
# Statistical analysis script for "An Empirical Analysis of the Utilization of 
# "Multiple Programming Languages in Open Source Projects. (EASE 2015)

# For more information contact Dr. Philip Mayer <mayer@pst.ifi.lmu.de>

# This script requires the file "07 result table for statistics.csv" in the working directory.

# --------- Load libraries -----------

# Package for smooth function estimation
library(mgcv)

# Library for descriptive statistics
library(pastecs)


# --------- Load data -----------

data <- read.csv(file="07 result table for statistics.csv", sep=";")


# --------- Descriptive statistics -----------

summary(data$noGPLs)
summary(data$noDSLs)
summary(data$noAllLang)

boxplot(data$noGPLs, data$noDSLs, data$noAllLang, names=c("GPLs", "DSLs", "Both"), ylab="Number of Languages",
        yaxp=c(0,40,20))


# --------- Inferential statistics -----------

# Prepare variables
data$mainLang <- as.factor(data$mainLang) # recode mainLang variable as factor
contrasts(data$mainLang) <- contr.treatment(levels(data$mainLang), base=11) # use dummy coding

data$numberOfLanguages <- data$noAllLang - 1 # Use "number of languages minus 1" (for Poisson)
data$age <- data$months_since_first_commit +1 # "Months since first commit plus 1"

data$contributors <- data$contributors_from_commits
data$commits <- data$commits_from_commits
data$size <- data$mainLangSize

# Run Poisson regression
model <- gam(numberOfLanguages ~ mainLang + I(log10(age)) + s(I(log10(contributors)))+
                         s(I(log10(commits))) + s(I(log10(size))),
                       data=data, family=quasipoisson(link="log"))

summary(model)
gam.check(model)
plot(model, all.terms=TRUE)

